:mod:`pyCTQW.MPI.io`
====================

.. currentmodule:: pyCTQW.MPI.io

.. caution::
  The functions available in this submodule have been
  designed to work with classes in the :class:`pyCTQW.MPI` module; that is, they are
  being called implicitly by the above classes, invisible to the user.
  
  It is not recommended that they be used by themselves, however it is
  possible to do so.

Summary
-------

.. autosummary::
    adjToH
    arrayToMat
    arrayToVec
    exportMat
    exportVec
    exportVecToMat
    loadMat
    loadMatToVec
    loadVec
    matToSparse
    vecToArray
    vecToArray0


Functions
---------

.. automodule:: pyCTQW.MPI.io
    :members:
    :show-inheritance:
